@@ -11,18 +11,6 @@ module Data.Graph.Inductive.Internal.RootPath (
 
 import Data.Graph.Inductive.Graph
 
-
-instance Eq a => Eq (LPath a) where
-  (LP [])        == (LP [])        = True
-  (LP ((_,x):_)) == (LP ((_,y):_)) = x==y
-  (LP _)         == (LP _)         = False
-
-instance Ord a => Ord (LPath a) where
-  compare (LP [])        (LP [])        = EQ
-  compare (LP ((_,x):_)) (LP ((_,y):_)) = compare x y
-  compare _ _ = error "LPath: cannot compare to empty paths"
-
-
 type LRTree a = [LPath a]
 type RTree = [Path]
 
@@ -33,10 +21,10 @@ first p xss  = case filter p xss of
 
 -- | Find the first path in a tree that starts with the given node
 findP :: Node -> LRTree a -> [LNode a]
-findP _ []                                  = []
-findP v ((LP []):ps)                        = findP v ps
-findP v ((LP (p@((w,_):_))):ps) | v==w      = p
-                                | otherwise = findP v ps
+findP _ []                                = []
+findP v (LP []:ps)                        = findP v ps
+findP v (LP (p@((w,_):_)):ps) | v==w      = p
+                              | otherwise = findP v ps
 
 getPath :: Node -> RTree -> Path
 getPath v = reverse . first (\(w:_)->w==v)
